;; Generated package description from system-packages.el  -*- no-byte-compile: t -*-
(define-package "system-packages" "1.0.11.0.20220409.62318" "functions to manage system packages" '((emacs "24.3")) :commit "c087d2c6e598f85fc2760324dce20104ea442fa3" :authors '(("J. Alexander Branham" . "alex.branham@gmail.com")) :maintainer '("J. Alexander Branham" . "alex.branham@gmail.com") :url "https://gitlab.com/jabranham/system-packages")
